summaryrefslogtreecommitdiffstats
path: root/content/browser/tcmalloc_internals_request_job.cc
diff options
context:
space:
mode:
authorvadimt <vadimt@chromium.org>2014-10-29 15:10:41 -0700
committerCommit bot <commit-bot@chromium.org>2014-10-29 22:11:04 +0000
commit09e7ebe02c71d923e4655a0ad5e151b97344f091 (patch)
tree116297765f286720af9aff161fafeca63486a1a6 /content/browser/tcmalloc_internals_request_job.cc
parent2ab60d98289be5804e38ea8fdebcf78740fca095 (diff)
downloadchromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.zip
chromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.tar.gz
chromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.tar.bz2
Switching profiler instrumentations from ScopedProfile to ScopedTracker. This will disable the instrumentations in all channels except Canary, and developer build. Instrumentations are only enabled in Browser process.
This will prevent Stable from sending increased amounts of UMA logs. Also, this will let us observe "true" (untouched by instrumentations) jankiness numbers every week in Dev channel. BUG=401560 Review URL: https://codereview.chromium.org/686963002 Cr-Commit-Position: refs/heads/master@{#301950}
Diffstat (limited to 'content/browser/tcmalloc_internals_request_job.cc')
-rw-r--r--content/browser/tcmalloc_internals_request_job.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/content/browser/tcmalloc_internals_request_job.cc b/content/browser/tcmalloc_internals_request_job.cc
index 74af822..750eae3 100644
--- a/content/browser/tcmalloc_internals_request_job.cc
+++ b/content/browser/tcmalloc_internals_request_job.cc
@@ -5,7 +5,7 @@
#include "content/browser/tcmalloc_internals_request_job.h"
#include "base/allocator/allocator_extension.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "content/common/child_process_messages.h"
#include "content/public/browser/browser_child_process_host_iterator.h"
#include "content/public/browser/browser_thread.h"
@@ -109,8 +109,8 @@ int TcmallocInternalsRequestJob::GetData(
std::string* charset,
std::string* data,
const net::CompletionCallback& callback) const {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422489 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422489 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"422489 TcmallocInternalsRequestJob::GetData"));